# bplib
A bilinear pairing library for petlib

Documentation: http://pythonhosted.org/bplib/

Pypi package: https://pypi.python.org/pypi/bplib

Based on Diego Aranha's OpenPairing: https://github.com/dfaranha/OpenPairing
